__author__ = 'nmaric'

from infobip.util.configuration import Configuration

infobip_base_url = "https://api.infobip.com"
infobip_username = "username"
infobip_password = "password"

configuration = Configuration(infobip_base_url, infobip_username, infobip_password)
